List of plugins
======================

If you would like to see your own alfred-plugin here, please contact
us!

- **alfred3-interact** offers functionality for interactive experiments.

  - GitHub: https://github.com/jobrachem/alfred3-interact
  - Documentation: https://jobrachem.github.io/alfred3-interact/build/html/index.html
